#ifdef __cplusplus
extern "C" {
#endif

#define SYSCALL_MAXARGS 8
enum argtype {
	ARG_INT,
	ARG_PTR,
	ARG_STR,
	ARG_UNKNOWN
};

const int MAX_SYSCALL_NUM = 456;

struct syscall_entry {
	const char *name;
	int nargs;
	enum argtype args[SYSCALL_MAXARGS];
} syscalls[] = {
	{.name = "syscall", .nargs = 1, .args = { ARG_INT, }},
	{.name = "exit", .nargs = 1, .args = { ARG_INT, }},
	{.name = "fork", .nargs = 1, .args = { ARG_UNKNOWN, }},
	{.name = "read", .nargs = 3, .args = { ARG_INT, ARG_STR, ARG_INT, }},
	{.name = "write", .nargs = 3, .args = { ARG_INT, ARG_STR, ARG_INT, }},
	{.name = "open", .nargs = 3, .args = { ARG_STR, ARG_UNKNOWN, ARG_INT, }},
	{.name = "close", .nargs = 1, .args = { ARG_INT, }},
	{.name = "wait4", .nargs = 4, .args = { ARG_INT, ARG_STR, ARG_INT, ARG_STR, }},
	{.name = "#8", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "link", .nargs = 2, .args = { ARG_STR, ARG_STR, }},
	{.name = "unlink", .nargs = 1, .args = { ARG_STR, }},
	{.name = "#11", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "chdir", .nargs = 1, .args = { ARG_STR, }},
	{.name = "fchdir", .nargs = 1, .args = { ARG_INT, }},
	{.name = "mknod", .nargs = 3, .args = { ARG_STR, ARG_INT, ARG_INT, }},
	{.name = "chmod", .nargs = 2, .args = { ARG_STR, ARG_INT, }},
	{.name = "chown", .nargs = 3, .args = { ARG_STR, ARG_INT, ARG_INT, }},
	{.name = "#17", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "getfsstat", .nargs = 3, .args = { ARG_STR, ARG_INT, ARG_UNKNOWN, }},
	{.name = "#19", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "getpid", .nargs = 1, .args = { ARG_UNKNOWN, }},
	{.name = "#21", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "#22", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "setuid", .nargs = 1, .args = { ARG_UNKNOWN, }},
	{.name = "getuid", .nargs = 1, .args = { ARG_UNKNOWN, }},
	{.name = "geteuid", .nargs = 1, .args = { ARG_UNKNOWN, }},
	{.name = "ptrace", .nargs = 4, .args = { ARG_INT, ARG_UNKNOWN, ARG_UNKNOWN, ARG_INT, }},
	{.name = "recvmsg", .nargs = 3, .args = { ARG_INT, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "sendmsg", .nargs = 3, .args = { ARG_INT, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "recvfrom", .nargs = 6, .args = { ARG_INT, ARG_STR, ARG_INT, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "accept", .nargs = 3, .args = { ARG_INT, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "getpeername", .nargs = 3, .args = { ARG_INT, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "getsockname", .nargs = 3, .args = { ARG_INT, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "access", .nargs = 2, .args = { ARG_STR, ARG_UNKNOWN, }},
	{.name = "chflags", .nargs = 2, .args = { ARG_STR, ARG_UNKNOWN, }},
	{.name = "fchflags", .nargs = 2, .args = { ARG_INT, ARG_UNKNOWN, }},
	{.name = "sync", .nargs = 1, .args = { ARG_UNKNOWN, }},
	{.name = "kill", .nargs = 3, .args = { ARG_INT, ARG_INT, ARG_INT, }},
	{.name = "#38", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "getppid", .nargs = 1, .args = { ARG_UNKNOWN, }},
	{.name = "#40", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "dup", .nargs = 1, .args = { ARG_INT, }},
	{.name = "pipe", .nargs = 1, .args = { ARG_UNKNOWN, }},
	{.name = "getegid", .nargs = 1, .args = { ARG_UNKNOWN, }},
	{.name = "#44", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "#45", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "sigaction", .nargs = 3, .args = { ARG_INT, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "getgid", .nargs = 1, .args = { ARG_UNKNOWN, }},
	{.name = "sigprocmask", .nargs = 3, .args = { ARG_INT, ARG_STR, ARG_STR, }},
	{.name = "getlogin", .nargs = 2, .args = { ARG_STR, ARG_INT, }},
	{.name = "setlogin", .nargs = 1, .args = { ARG_STR, }},
	{.name = "acct", .nargs = 1, .args = { ARG_STR, }},
	{.name = "sigpending", .nargs = 1, .args = { ARG_UNKNOWN, }},
	{.name = "sigaltstack", .nargs = 2, .args = { ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "ioctl", .nargs = 3, .args = { ARG_INT, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "reboot", .nargs = 2, .args = { ARG_INT, ARG_STR, }},
	{.name = "revoke", .nargs = 1, .args = { ARG_STR, }},
	{.name = "symlink", .nargs = 2, .args = { ARG_STR, ARG_STR, }},
	{.name = "readlink", .nargs = 3, .args = { ARG_STR, ARG_STR, ARG_INT, }},
	{.name = "execve", .nargs = 3, .args = { ARG_STR, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "umask", .nargs = 1, .args = { ARG_INT, }},
	{.name = "chroot", .nargs = 1, .args = { ARG_STR, }},
	{.name = "#62", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "#63", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "#64", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "msync", .nargs = 3, .args = { ARG_UNKNOWN, ARG_INT, ARG_UNKNOWN, }},
	{.name = "vfork", .nargs = 1, .args = { ARG_UNKNOWN, }},
	{.name = "#67", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "#68", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "#69", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "#70", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "#71", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "#72", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "munmap", .nargs = 2, .args = { ARG_UNKNOWN, ARG_INT, }},
	{.name = "mprotect", .nargs = 3, .args = { ARG_UNKNOWN, ARG_INT, ARG_INT, }},
	{.name = "madvise", .nargs = 3, .args = { ARG_UNKNOWN, ARG_INT, ARG_INT, }},
	{.name = "#76", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "#77", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "mincore", .nargs = 3, .args = { ARG_STR, ARG_INT, ARG_STR, }},
	{.name = "getgroups", .nargs = 2, .args = { ARG_INT, ARG_UNKNOWN, }},
	{.name = "setgroups", .nargs = 2, .args = { ARG_INT, ARG_UNKNOWN, }},
	{.name = "getpgrp", .nargs = 1, .args = { ARG_UNKNOWN, }},
	{.name = "setpgid", .nargs = 2, .args = { ARG_INT, ARG_INT, }},
	{.name = "setitimer", .nargs = 3, .args = { ARG_INT, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "#84", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "swapon", .nargs = 1, .args = { ARG_UNKNOWN, }},
	{.name = "getitimer", .nargs = 2, .args = { ARG_INT, ARG_UNKNOWN, }},
	{.name = "#87", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "#88", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "getdtablesize", .nargs = 1, .args = { ARG_UNKNOWN, }},
	{.name = "dup2", .nargs = 2, .args = { ARG_INT, ARG_INT, }},
	{.name = "#91", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "fcntl", .nargs = 3, .args = { ARG_INT, ARG_INT, ARG_UNKNOWN, }},
	{.name = "select", .nargs = 5, .args = { ARG_INT, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "#94", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "fsync", .nargs = 1, .args = { ARG_INT, }},
	{.name = "setpriority", .nargs = 3, .args = { ARG_INT, ARG_UNKNOWN, ARG_INT, }},
	{.name = "socket", .nargs = 3, .args = { ARG_INT, ARG_INT, ARG_INT, }},
	{.name = "connect", .nargs = 3, .args = { ARG_INT, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "#99", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "getpriority", .nargs = 2, .args = { ARG_INT, ARG_UNKNOWN, }},
	{.name = "#101", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "#102", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "#103", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "bind", .nargs = 3, .args = { ARG_INT, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "setsockopt", .nargs = 5, .args = { ARG_INT, ARG_INT, ARG_INT, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "listen", .nargs = 2, .args = { ARG_INT, ARG_INT, }},
	{.name = "#107", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "#108", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "#109", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "#110", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "sigsuspend", .nargs = 1, .args = { ARG_UNKNOWN, }},
	{.name = "#112", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "#113", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "#114", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "#115", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "gettimeofday", .nargs = 2, .args = { ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "getrusage", .nargs = 2, .args = { ARG_INT, ARG_UNKNOWN, }},
	{.name = "getsockopt", .nargs = 5, .args = { ARG_INT, ARG_INT, ARG_INT, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "#119", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "readv", .nargs = 3, .args = { ARG_INT, ARG_UNKNOWN, ARG_INT, }},
	{.name = "writev", .nargs = 3, .args = { ARG_INT, ARG_UNKNOWN, ARG_INT, }},
	{.name = "settimeofday", .nargs = 2, .args = { ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "fchown", .nargs = 3, .args = { ARG_INT, ARG_INT, ARG_INT, }},
	{.name = "fchmod", .nargs = 2, .args = { ARG_INT, ARG_INT, }},
	{.name = "#125", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "setreuid", .nargs = 2, .args = { ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "setregid", .nargs = 2, .args = { ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "rename", .nargs = 2, .args = { ARG_STR, ARG_STR, }},
	{.name = "#129", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "#130", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "flock", .nargs = 2, .args = { ARG_INT, ARG_INT, }},
	{.name = "mkfifo", .nargs = 2, .args = { ARG_STR, ARG_INT, }},
	{.name = "sendto", .nargs = 6, .args = { ARG_INT, ARG_UNKNOWN, ARG_INT, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "shutdown", .nargs = 2, .args = { ARG_INT, ARG_INT, }},
	{.name = "socketpair", .nargs = 4, .args = { ARG_INT, ARG_INT, ARG_INT, ARG_UNKNOWN, }},
	{.name = "mkdir", .nargs = 2, .args = { ARG_STR, ARG_INT, }},
	{.name = "rmdir", .nargs = 1, .args = { ARG_STR, }},
	{.name = "utimes", .nargs = 2, .args = { ARG_STR, ARG_UNKNOWN, }},
	{.name = "futimes", .nargs = 2, .args = { ARG_INT, ARG_UNKNOWN, }},
	{.name = "adjtime", .nargs = 2, .args = { ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "#141", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "gethostuuid", .nargs = 3, .args = { ARG_STR, ARG_UNKNOWN, ARG_INT, }},
	{.name = "#143", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "#144", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "#145", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "#146", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "setsid", .nargs = 1, .args = { ARG_UNKNOWN, }},
	{.name = "#148", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "#149", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "#150", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "getpgid", .nargs = 1, .args = { ARG_UNKNOWN, }},
	{.name = "setprivexec", .nargs = 1, .args = { ARG_UNKNOWN, }},
	{.name = "pread", .nargs = 4, .args = { ARG_INT, ARG_STR, ARG_INT, ARG_UNKNOWN, }},
	{.name = "pwrite", .nargs = 4, .args = { ARG_INT, ARG_STR, ARG_INT, ARG_UNKNOWN, }},
	{.name = "nfssvc", .nargs = 2, .args = { ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "#156", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "statfs", .nargs = 2, .args = { ARG_STR, ARG_UNKNOWN, }},
	{.name = "fstatfs", .nargs = 2, .args = { ARG_INT, ARG_UNKNOWN, }},
	{.name = "unmount", .nargs = 2, .args = { ARG_STR, ARG_UNKNOWN, }},
	{.name = "#160", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "getfh", .nargs = 2, .args = { ARG_STR, ARG_UNKNOWN, }},
	{.name = "#162", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "#163", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "#164", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "quotactl", .nargs = 4, .args = { ARG_STR, ARG_INT, ARG_INT, ARG_UNKNOWN, }},
	{.name = "#166", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "mount", .nargs = 4, .args = { ARG_STR, ARG_STR, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "#168", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "csops", .nargs = 4, .args = { ARG_UNKNOWN, ARG_INT, ARG_STR, ARG_INT, }},
	{.name = "csops_audittoken", .nargs = 5, .args = { ARG_UNKNOWN, ARG_INT, ARG_STR, ARG_INT, ARG_STR, }},
	{.name = "#171", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "#172", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "waitid", .nargs = 4, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_INT, }},
	{.name = "#174", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "#175", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "#176", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "#177", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "#178", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "#179", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "kdebug_trace", .nargs = 6, .args = { ARG_INT, ARG_INT, ARG_INT, ARG_INT, ARG_INT, ARG_INT, }},
	{.name = "setgid", .nargs = 1, .args = { ARG_UNKNOWN, }},
	{.name = "setegid", .nargs = 1, .args = { ARG_UNKNOWN, }},
	{.name = "seteuid", .nargs = 1, .args = { ARG_UNKNOWN, }},
	{.name = "sigreturn", .nargs = 2, .args = { ARG_UNKNOWN, ARG_INT, }},
	{.name = "chud", .nargs = 6, .args = { ARG_INT, ARG_INT, ARG_INT, ARG_INT, ARG_INT, ARG_INT, }},
	{.name = "#186", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "fdatasync", .nargs = 1, .args = { ARG_INT, }},
	{.name = "stat", .nargs = 2, .args = { ARG_STR, ARG_STR, }},
	{.name = "fstat", .nargs = 2, .args = { ARG_INT, ARG_STR, }},
	{.name = "lstat", .nargs = 2, .args = { ARG_STR, ARG_STR, }},
	{.name = "pathconf", .nargs = 2, .args = { ARG_STR, ARG_INT, }},
	{.name = "fpathconf", .nargs = 2, .args = { ARG_INT, ARG_INT, }},
	{.name = "#193", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "getrlimit", .nargs = 2, .args = { ARG_INT, ARG_UNKNOWN, }},
	{.name = "setrlimit", .nargs = 2, .args = { ARG_INT, ARG_UNKNOWN, }},
	{.name = "getdirentries", .nargs = 4, .args = { ARG_INT, ARG_STR, ARG_INT, ARG_UNKNOWN, }},
	{.name = "mmap", .nargs = 6, .args = { ARG_UNKNOWN, ARG_INT, ARG_INT, ARG_UNKNOWN, ARG_INT, ARG_UNKNOWN, }},
	{.name = "#198", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "lseek", .nargs = 3, .args = { ARG_INT, ARG_UNKNOWN, ARG_INT, }},
	{.name = "truncate", .nargs = 2, .args = { ARG_STR, ARG_UNKNOWN, }},
	{.name = "ftruncate", .nargs = 2, .args = { ARG_INT, ARG_UNKNOWN, }},
	{.name = "__sysctl", .nargs = 6, .args = { ARG_UNKNOWN, ARG_INT, ARG_STR, ARG_UNKNOWN, ARG_STR, ARG_INT, }},
	{.name = "mlock", .nargs = 2, .args = { ARG_UNKNOWN, ARG_INT, }},
	{.name = "munlock", .nargs = 2, .args = { ARG_UNKNOWN, ARG_INT, }},
	{.name = "undelete", .nargs = 1, .args = { ARG_STR, }},
	{.name = "#206", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "#207", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "#208", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "#209", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "#210", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "#211", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "#212", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "#213", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "#214", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "#215", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "open_dprotected_np", .nargs = 5, .args = { ARG_STR, ARG_UNKNOWN, ARG_INT, ARG_UNKNOWN, ARG_INT, }},
	{.name = "#217", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "#218", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "#219", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "getattrlist", .nargs = 5, .args = { ARG_STR, ARG_UNKNOWN, ARG_STR, ARG_INT, ARG_UNKNOWN, }},
	{.name = "setattrlist", .nargs = 5, .args = { ARG_STR, ARG_UNKNOWN, ARG_STR, ARG_INT, ARG_UNKNOWN, }},
	{.name = "getdirentriesattr", .nargs = 8, .args = { ARG_INT, ARG_UNKNOWN, ARG_STR, ARG_INT, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "exchangedata", .nargs = 3, .args = { ARG_STR, ARG_STR, ARG_UNKNOWN, }},
	{.name = "#224", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "searchfs", .nargs = 6, .args = { ARG_STR, ARG_UNKNOWN, ARG_UNKNOWN, ARG_INT, ARG_INT, ARG_UNKNOWN, }},
	{.name = "delete", .nargs = 1, .args = { ARG_STR, }},
	{.name = "copyfile", .nargs = 4, .args = { ARG_STR, ARG_STR, ARG_INT, ARG_UNKNOWN, }},
	{.name = "fgetattrlist", .nargs = 5, .args = { ARG_INT, ARG_UNKNOWN, ARG_STR, ARG_INT, ARG_UNKNOWN, }},
	{.name = "fsetattrlist", .nargs = 5, .args = { ARG_INT, ARG_UNKNOWN, ARG_STR, ARG_INT, ARG_UNKNOWN, }},
	{.name = "poll", .nargs = 3, .args = { ARG_UNKNOWN, ARG_INT, ARG_INT, }},
	{.name = "watchevent", .nargs = 2, .args = { ARG_UNKNOWN, ARG_INT, }},
	{.name = "waitevent", .nargs = 2, .args = { ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "modwatch", .nargs = 2, .args = { ARG_UNKNOWN, ARG_INT, }},
	{.name = "getxattr", .nargs = 6, .args = { ARG_STR, ARG_STR, ARG_STR, ARG_INT, ARG_INT, ARG_INT, }},
	{.name = "fgetxattr", .nargs = 6, .args = { ARG_INT, ARG_STR, ARG_STR, ARG_INT, ARG_INT, ARG_INT, }},
	{.name = "setxattr", .nargs = 6, .args = { ARG_STR, ARG_STR, ARG_STR, ARG_INT, ARG_INT, ARG_INT, }},
	{.name = "fsetxattr", .nargs = 6, .args = { ARG_INT, ARG_STR, ARG_STR, ARG_INT, ARG_INT, ARG_INT, }},
	{.name = "removexattr", .nargs = 3, .args = { ARG_STR, ARG_STR, ARG_INT, }},
	{.name = "fremovexattr", .nargs = 3, .args = { ARG_INT, ARG_STR, ARG_INT, }},
	{.name = "listxattr", .nargs = 4, .args = { ARG_STR, ARG_STR, ARG_INT, ARG_INT, }},
	{.name = "flistxattr", .nargs = 4, .args = { ARG_INT, ARG_STR, ARG_INT, ARG_INT, }},
	{.name = "fsctl", .nargs = 4, .args = { ARG_STR, ARG_UNKNOWN, ARG_UNKNOWN, ARG_INT, }},
	{.name = "initgroups", .nargs = 3, .args = { ARG_INT, ARG_UNKNOWN, ARG_INT, }},
	{.name = "posix_spawn", .nargs = 5, .args = { ARG_UNKNOWN, ARG_STR, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "ffsctl", .nargs = 4, .args = { ARG_INT, ARG_UNKNOWN, ARG_UNKNOWN, ARG_INT, }},
	{.name = "#246", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "nfsclnt", .nargs = 2, .args = { ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "fhopen", .nargs = 2, .args = { ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "#249", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "minherit", .nargs = 3, .args = { ARG_STR, ARG_INT, ARG_INT, }},
	{.name = "semsys", .nargs = 5, .args = { ARG_INT, ARG_INT, ARG_INT, ARG_INT, ARG_INT, }},
	{.name = "msgsys", .nargs = 5, .args = { ARG_INT, ARG_INT, ARG_INT, ARG_INT, ARG_INT, }},
	{.name = "shmsys", .nargs = 4, .args = { ARG_INT, ARG_INT, ARG_INT, ARG_INT, }},
	{.name = "semctl", .nargs = 4, .args = { ARG_INT, ARG_INT, ARG_INT, ARG_UNKNOWN, }},
	{.name = "semget", .nargs = 3, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_INT, }},
	{.name = "semop", .nargs = 3, .args = { ARG_INT, ARG_UNKNOWN, ARG_INT, }},
	{.name = "#257", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "msgctl", .nargs = 3, .args = { ARG_INT, ARG_INT, ARG_UNKNOWN, }},
	{.name = "msgget", .nargs = 2, .args = { ARG_UNKNOWN, ARG_INT, }},
	{.name = "msgsnd", .nargs = 4, .args = { ARG_INT, ARG_STR, ARG_INT, ARG_INT, }},
	{.name = "msgrcv", .nargs = 5, .args = { ARG_INT, ARG_STR, ARG_INT, ARG_UNKNOWN, ARG_INT, }},
	{.name = "shmat", .nargs = 3, .args = { ARG_INT, ARG_STR, ARG_INT, }},
	{.name = "shmctl", .nargs = 3, .args = { ARG_INT, ARG_INT, ARG_UNKNOWN, }},
	{.name = "shmdt", .nargs = 1, .args = { ARG_STR, }},
	{.name = "shmget", .nargs = 3, .args = { ARG_UNKNOWN, ARG_INT, ARG_INT, }},
	{.name = "shm_open", .nargs = 3, .args = { ARG_STR, ARG_UNKNOWN, ARG_INT, }},
	{.name = "shm_unlink", .nargs = 1, .args = { ARG_STR, }},
	{.name = "sem_open", .nargs = 4, .args = { ARG_STR, ARG_UNKNOWN, ARG_INT, ARG_INT, }},
	{.name = "sem_close", .nargs = 1, .args = { ARG_UNKNOWN, }},
	{.name = "sem_unlink", .nargs = 1, .args = { ARG_STR, }},
	{.name = "sem_wait", .nargs = 1, .args = { ARG_UNKNOWN, }},
	{.name = "sem_trywait", .nargs = 1, .args = { ARG_UNKNOWN, }},
	{.name = "sem_post", .nargs = 1, .args = { ARG_UNKNOWN, }},
	{.name = "sem_getvalue", .nargs = 2, .args = { ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "sem_init", .nargs = 3, .args = { ARG_UNKNOWN, ARG_INT, ARG_INT, }},
	{.name = "sem_destroy", .nargs = 1, .args = { ARG_UNKNOWN, }},
	{.name = "open_extended", .nargs = 6, .args = { ARG_STR, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_INT, ARG_STR, }},
	{.name = "umask_extended", .nargs = 2, .args = { ARG_INT, ARG_STR, }},
	{.name = "stat_extended", .nargs = 4, .args = { ARG_STR, ARG_STR, ARG_STR, ARG_STR, }},
	{.name = "lstat_extended", .nargs = 4, .args = { ARG_STR, ARG_STR, ARG_STR, ARG_STR, }},
	{.name = "fstat_extended", .nargs = 4, .args = { ARG_INT, ARG_STR, ARG_STR, ARG_STR, }},
	{.name = "chmod_extended", .nargs = 5, .args = { ARG_STR, ARG_UNKNOWN, ARG_UNKNOWN, ARG_INT, ARG_STR, }},
	{.name = "fchmod_extended", .nargs = 5, .args = { ARG_INT, ARG_UNKNOWN, ARG_UNKNOWN, ARG_INT, ARG_STR, }},
	{.name = "access_extended", .nargs = 4, .args = { ARG_STR, ARG_INT, ARG_STR, ARG_UNKNOWN, }},
	{.name = "settid", .nargs = 2, .args = { ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "gettid", .nargs = 2, .args = { ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "setsgroups", .nargs = 2, .args = { ARG_INT, ARG_STR, }},
	{.name = "getsgroups", .nargs = 2, .args = { ARG_STR, ARG_STR, }},
	{.name = "setwgroups", .nargs = 2, .args = { ARG_INT, ARG_STR, }},
	{.name = "getwgroups", .nargs = 2, .args = { ARG_STR, ARG_STR, }},
	{.name = "mkfifo_extended", .nargs = 5, .args = { ARG_STR, ARG_UNKNOWN, ARG_UNKNOWN, ARG_INT, ARG_STR, }},
	{.name = "mkdir_extended", .nargs = 5, .args = { ARG_STR, ARG_UNKNOWN, ARG_UNKNOWN, ARG_INT, ARG_STR, }},
	{.name = "identitysvc", .nargs = 2, .args = { ARG_INT, ARG_STR, }},
	{.name = "shared_region_check_np", .nargs = 1, .args = { ARG_UNKNOWN, }},
	{.name = "#295", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "vm_pressure_monitor", .nargs = 3, .args = { ARG_INT, ARG_INT, ARG_UNKNOWN, }},
	{.name = "psynch_rw_longrdlock", .nargs = 5, .args = { ARG_STR, ARG_INT, ARG_INT, ARG_INT, ARG_UNKNOWN, }},
	{.name = "psynch_rw_yieldwrlock", .nargs = 5, .args = { ARG_STR, ARG_INT, ARG_INT, ARG_INT, ARG_UNKNOWN, }},
	{.name = "enosys", .nargs = 1, .args = { ARG_UNKNOWN, }},
	{.name = "enosys", .nargs = 1, .args = { ARG_UNKNOWN, }},
	{.name = "psynch_mutexwait", .nargs = 5, .args = { ARG_STR, ARG_INT, ARG_INT, ARG_INT, ARG_UNKNOWN, }},
	{.name = "psynch_mutexdrop", .nargs = 5, .args = { ARG_STR, ARG_INT, ARG_INT, ARG_INT, ARG_UNKNOWN, }},
	{.name = "psynch_cvbroad", .nargs = 7, .args = { ARG_STR, ARG_INT, ARG_INT, ARG_UNKNOWN, ARG_STR, ARG_INT, ARG_INT, }},
	{.name = "psynch_cvsignal", .nargs = 8, .args = { ARG_STR, ARG_INT, ARG_INT, ARG_INT, ARG_STR, ARG_INT, ARG_INT, ARG_UNKNOWN, }},
	{.name = "psynch_cvwait", .nargs = 8, .args = { ARG_STR, ARG_INT, ARG_INT, ARG_STR, ARG_INT, ARG_UNKNOWN, ARG_INT, ARG_INT, }},
	{.name = "psynch_rw_rdlock", .nargs = 5, .args = { ARG_STR, ARG_INT, ARG_INT, ARG_INT, ARG_UNKNOWN, }},
	{.name = "psynch_rw_wrlock", .nargs = 5, .args = { ARG_STR, ARG_INT, ARG_INT, ARG_INT, ARG_UNKNOWN, }},
	{.name = "psynch_rw_unlock", .nargs = 5, .args = { ARG_STR, ARG_INT, ARG_INT, ARG_INT, ARG_UNKNOWN, }},
	{.name = "psynch_rw_unlock2", .nargs = 5, .args = { ARG_STR, ARG_INT, ARG_INT, ARG_INT, ARG_UNKNOWN, }},
	{.name = "getsid", .nargs = 1, .args = { ARG_UNKNOWN, }},
	{.name = "settid_with_pid", .nargs = 2, .args = { ARG_UNKNOWN, ARG_INT, }},
	{.name = "psynch_cvclrprepost", .nargs = 7, .args = { ARG_STR, ARG_INT, ARG_INT, ARG_INT, ARG_INT, ARG_INT, ARG_UNKNOWN, }},
	{.name = "aio_fsync", .nargs = 2, .args = { ARG_INT, ARG_STR, }},
	{.name = "aio_return", .nargs = 1, .args = { ARG_STR, }},
	{.name = "aio_suspend", .nargs = 3, .args = { ARG_STR, ARG_INT, ARG_STR, }},
	{.name = "aio_cancel", .nargs = 2, .args = { ARG_INT, ARG_STR, }},
	{.name = "aio_error", .nargs = 1, .args = { ARG_STR, }},
	{.name = "aio_read", .nargs = 1, .args = { ARG_STR, }},
	{.name = "aio_write", .nargs = 1, .args = { ARG_STR, }},
	{.name = "lio_listio", .nargs = 4, .args = { ARG_INT, ARG_STR, ARG_INT, ARG_STR, }},
	{.name = "#321", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "iopolicysys", .nargs = 2, .args = { ARG_INT, ARG_STR, }},
	{.name = "process_policy", .nargs = 7, .args = { ARG_INT, ARG_INT, ARG_INT, ARG_INT, ARG_STR, ARG_UNKNOWN, ARG_INT, }},
	{.name = "mlockall", .nargs = 1, .args = { ARG_INT, }},
	{.name = "munlockall", .nargs = 1, .args = { ARG_INT, }},
	{.name = "#326", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "issetugid", .nargs = 1, .args = { ARG_UNKNOWN, }},
	{.name = "__pthread_kill", .nargs = 2, .args = { ARG_INT, ARG_INT, }},
	{.name = "__pthread_sigmask", .nargs = 3, .args = { ARG_INT, ARG_STR, ARG_STR, }},
	{.name = "__sigwait", .nargs = 2, .args = { ARG_STR, ARG_STR, }},
	{.name = "__disable_threadsignal", .nargs = 1, .args = { ARG_INT, }},
	{.name = "__pthread_markcancel", .nargs = 1, .args = { ARG_INT, }},
	{.name = "__pthread_canceled", .nargs = 1, .args = { ARG_INT, }},
	{.name = "__semwait_signal", .nargs = 6, .args = { ARG_INT, ARG_INT, ARG_INT, ARG_INT, ARG_INT, ARG_INT, }},
	{.name = "#335", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "proc_info", .nargs = 6, .args = { ARG_INT, ARG_INT, ARG_INT, ARG_INT, ARG_STR, ARG_INT, }},
	{.name = "sendfile", .nargs = 6, .args = { ARG_INT, ARG_INT, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "stat64", .nargs = 2, .args = { ARG_STR, ARG_STR, }},
	{.name = "fstat64", .nargs = 2, .args = { ARG_INT, ARG_STR, }},
	{.name = "lstat64", .nargs = 2, .args = { ARG_STR, ARG_STR, }},
	{.name = "stat64_extended", .nargs = 4, .args = { ARG_STR, ARG_STR, ARG_STR, ARG_STR, }},
	{.name = "lstat64_extended", .nargs = 4, .args = { ARG_STR, ARG_STR, ARG_STR, ARG_STR, }},
	{.name = "fstat64_extended", .nargs = 4, .args = { ARG_INT, ARG_STR, ARG_STR, ARG_STR, }},
	{.name = "getdirentries64", .nargs = 4, .args = { ARG_INT, ARG_STR, ARG_INT, ARG_UNKNOWN, }},
	{.name = "statfs64", .nargs = 2, .args = { ARG_STR, ARG_UNKNOWN, }},
	{.name = "fstatfs64", .nargs = 2, .args = { ARG_INT, ARG_UNKNOWN, }},
	{.name = "getfsstat64", .nargs = 3, .args = { ARG_STR, ARG_INT, ARG_UNKNOWN, }},
	{.name = "__pthread_chdir", .nargs = 1, .args = { ARG_STR, }},
	{.name = "__pthread_fchdir", .nargs = 1, .args = { ARG_INT, }},
	{.name = "audit", .nargs = 2, .args = { ARG_STR, ARG_INT, }},
	{.name = "auditon", .nargs = 3, .args = { ARG_INT, ARG_STR, ARG_INT, }},
	{.name = "#352", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "getauid", .nargs = 1, .args = { ARG_UNKNOWN, }},
	{.name = "setauid", .nargs = 1, .args = { ARG_UNKNOWN, }},
	{.name = "#355", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "#356", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "getaudit_addr", .nargs = 2, .args = { ARG_UNKNOWN, ARG_INT, }},
	{.name = "setaudit_addr", .nargs = 2, .args = { ARG_UNKNOWN, ARG_INT, }},
	{.name = "auditctl", .nargs = 1, .args = { ARG_STR, }},
	{.name = "bsdthread_create", .nargs = 5, .args = { ARG_STR, ARG_STR, ARG_STR, ARG_STR, ARG_UNKNOWN, }},
	{.name = "bsdthread_terminate", .nargs = 4, .args = { ARG_STR, ARG_INT, ARG_INT, ARG_INT, }},
	{.name = "kqueue", .nargs = 1, .args = { ARG_UNKNOWN, }},
	{.name = "kevent", .nargs = 6, .args = { ARG_INT, ARG_UNKNOWN, ARG_INT, ARG_UNKNOWN, ARG_INT, ARG_UNKNOWN, }},
	{.name = "lchown", .nargs = 3, .args = { ARG_STR, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "stack_snapshot", .nargs = 5, .args = { ARG_UNKNOWN, ARG_STR, ARG_INT, ARG_UNKNOWN, ARG_INT, }},
	{.name = "bsdthread_register", .nargs = 6, .args = { ARG_STR, ARG_STR, ARG_INT, ARG_STR, ARG_STR, ARG_INT, }},
	{.name = "workq_open", .nargs = 1, .args = { ARG_UNKNOWN, }},
	{.name = "workq_kernreturn", .nargs = 4, .args = { ARG_INT, ARG_STR, ARG_INT, ARG_INT, }},
	{.name = "kevent64", .nargs = 7, .args = { ARG_INT, ARG_UNKNOWN, ARG_INT, ARG_UNKNOWN, ARG_INT, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "__old_semwait_signal", .nargs = 5, .args = { ARG_INT, ARG_INT, ARG_INT, ARG_INT, ARG_UNKNOWN, }},
	{.name = "__old_semwait_signal_nocancel", .nargs = 5, .args = { ARG_INT, ARG_INT, ARG_INT, ARG_INT, ARG_UNKNOWN, }},
	{.name = "", .nargs = 1, .args = { ARG_UNKNOWN, }},
	{.name = "ledger", .nargs = 4, .args = { ARG_INT, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "#374", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "#375", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "#376", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "#377", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "#378", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "#379", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "__mac_execve", .nargs = 4, .args = { ARG_STR, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "enosys", .nargs = 1, .args = { ARG_UNKNOWN, }},
	{.name = "__mac_get_file", .nargs = 2, .args = { ARG_STR, ARG_UNKNOWN, }},
	{.name = "__mac_set_file", .nargs = 2, .args = { ARG_STR, ARG_UNKNOWN, }},
	{.name = "__mac_get_link", .nargs = 2, .args = { ARG_STR, ARG_UNKNOWN, }},
	{.name = "__mac_set_link", .nargs = 2, .args = { ARG_STR, ARG_UNKNOWN, }},
	{.name = "__mac_get_proc", .nargs = 1, .args = { ARG_UNKNOWN, }},
	{.name = "__mac_set_proc", .nargs = 1, .args = { ARG_UNKNOWN, }},
	{.name = "__mac_get_fd", .nargs = 2, .args = { ARG_INT, ARG_UNKNOWN, }},
	{.name = "__mac_set_fd", .nargs = 2, .args = { ARG_INT, ARG_UNKNOWN, }},
	{.name = "__mac_get_pid", .nargs = 2, .args = { ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "__mac_get_lcid", .nargs = 2, .args = { ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "__mac_get_lctx", .nargs = 1, .args = { ARG_UNKNOWN, }},
	{.name = "__mac_set_lctx", .nargs = 1, .args = { ARG_UNKNOWN, }},
	{.name = "setlcid", .nargs = 2, .args = { ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "getlcid", .nargs = 1, .args = { ARG_UNKNOWN, }},
	{.name = "read_nocancel", .nargs = 3, .args = { ARG_INT, ARG_STR, ARG_INT, }},
	{.name = "write_nocancel", .nargs = 3, .args = { ARG_INT, ARG_STR, ARG_INT, }},
	{.name = "open_nocancel", .nargs = 3, .args = { ARG_STR, ARG_UNKNOWN, ARG_INT, }},
	{.name = "close_nocancel", .nargs = 1, .args = { ARG_INT, }},
	{.name = "wait4_nocancel", .nargs = 4, .args = { ARG_INT, ARG_STR, ARG_INT, ARG_STR, }},
	{.name = "recvmsg_nocancel", .nargs = 3, .args = { ARG_INT, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "sendmsg_nocancel", .nargs = 3, .args = { ARG_INT, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "recvfrom_nocancel", .nargs = 6, .args = { ARG_INT, ARG_STR, ARG_INT, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "accept_nocancel", .nargs = 3, .args = { ARG_INT, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "msync_nocancel", .nargs = 3, .args = { ARG_UNKNOWN, ARG_INT, ARG_UNKNOWN, }},
	{.name = "fcntl_nocancel", .nargs = 3, .args = { ARG_INT, ARG_INT, ARG_UNKNOWN, }},
	{.name = "select_nocancel", .nargs = 5, .args = { ARG_INT, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "fsync_nocancel", .nargs = 1, .args = { ARG_INT, }},
	{.name = "connect_nocancel", .nargs = 3, .args = { ARG_INT, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "sigsuspend_nocancel", .nargs = 1, .args = { ARG_UNKNOWN, }},
	{.name = "readv_nocancel", .nargs = 3, .args = { ARG_INT, ARG_UNKNOWN, ARG_INT, }},
	{.name = "writev_nocancel", .nargs = 3, .args = { ARG_INT, ARG_UNKNOWN, ARG_INT, }},
	{.name = "sendto_nocancel", .nargs = 6, .args = { ARG_INT, ARG_UNKNOWN, ARG_INT, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "pread_nocancel", .nargs = 4, .args = { ARG_INT, ARG_STR, ARG_INT, ARG_UNKNOWN, }},
	{.name = "pwrite_nocancel", .nargs = 4, .args = { ARG_INT, ARG_STR, ARG_INT, ARG_UNKNOWN, }},
	{.name = "waitid_nocancel", .nargs = 4, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_INT, }},
	{.name = "poll_nocancel", .nargs = 3, .args = { ARG_UNKNOWN, ARG_INT, ARG_INT, }},
	{.name = "msgsnd_nocancel", .nargs = 4, .args = { ARG_INT, ARG_STR, ARG_INT, ARG_INT, }},
	{.name = "msgrcv_nocancel", .nargs = 5, .args = { ARG_INT, ARG_STR, ARG_INT, ARG_UNKNOWN, ARG_INT, }},
	{.name = "sem_wait_nocancel", .nargs = 1, .args = { ARG_UNKNOWN, }},
	{.name = "aio_suspend_nocancel", .nargs = 3, .args = { ARG_STR, ARG_INT, ARG_STR, }},
	{.name = "__sigwait_nocancel", .nargs = 2, .args = { ARG_STR, ARG_STR, }},
	{.name = "__semwait_signal_nocancel", .nargs = 6, .args = { ARG_INT, ARG_INT, ARG_INT, ARG_INT, ARG_INT, ARG_INT, }},
	{.name = "__mac_mount", .nargs = 5, .args = { ARG_STR, ARG_STR, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "__mac_get_mount", .nargs = 2, .args = { ARG_STR, ARG_UNKNOWN, }},
	{.name = "__mac_getfsstat", .nargs = 5, .args = { ARG_STR, ARG_INT, ARG_STR, ARG_INT, ARG_UNKNOWN, }},
	{.name = "fsgetpath", .nargs = 4, .args = { ARG_STR, ARG_INT, ARG_STR, ARG_INT, }},
	{.name = "audit_session_self", .nargs = 1, .args = { ARG_UNKNOWN, }},
	{.name = "audit_session_join", .nargs = 1, .args = { ARG_UNKNOWN, }},
	{.name = "fileport_makeport", .nargs = 2, .args = { ARG_INT, ARG_STR, }},
	{.name = "fileport_makefd", .nargs = 1, .args = { ARG_UNKNOWN, }},
	{.name = "audit_session_port", .nargs = 2, .args = { ARG_UNKNOWN, ARG_STR, }},
	{.name = "pid_suspend", .nargs = 1, .args = { ARG_INT, }},
	{.name = "pid_resume", .nargs = 1, .args = { ARG_INT, }},
	{.name = "#435", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "#436", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "#437", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "shared_region_map_and_slide_np", .nargs = 6, .args = { ARG_INT, ARG_INT, ARG_UNKNOWN, ARG_INT, ARG_UNKNOWN, ARG_INT, }},
	{.name = "kas_info", .nargs = 3, .args = { ARG_INT, ARG_STR, ARG_UNKNOWN, }},
	{.name = "memorystatus_control", .nargs = 5, .args = { ARG_INT, ARG_INT, ARG_UNKNOWN, ARG_STR, ARG_INT, }},
	{.name = "guarded_open_np", .nargs = 5, .args = { ARG_STR, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_INT, }},
	{.name = "guarded_close_np", .nargs = 2, .args = { ARG_INT, ARG_UNKNOWN, }},
	{.name = "guarded_kqueue_np", .nargs = 2, .args = { ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "change_fdguard_np", .nargs = 6, .args = { ARG_INT, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "#445", .nargs = 6, .args = { ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "proc_rlimit_control", .nargs = 3, .args = { ARG_UNKNOWN, ARG_INT, ARG_STR, }},
	{.name = "connectx", .nargs = 8, .args = { ARG_INT, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_UNKNOWN, ARG_INT, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "disconnectx", .nargs = 3, .args = { ARG_INT, ARG_UNKNOWN, ARG_UNKNOWN, }},
	{.name = "peeloff", .nargs = 2, .args = { ARG_INT, ARG_UNKNOWN, }},
	{.name = "socket_delegate", .nargs = 4, .args = { ARG_INT, ARG_INT, ARG_INT, ARG_UNKNOWN, }},
	{.name = "telemetry", .nargs = 6, .args = { ARG_INT, ARG_INT, ARG_INT, ARG_INT, ARG_INT, ARG_INT, }},
	{.name = "proc_uuid_policy", .nargs = 4, .args = { ARG_INT, ARG_UNKNOWN, ARG_INT, ARG_UNKNOWN, }},
	{.name = "memorystatus_get_level", .nargs = 1, .args = { ARG_STR, }},
	{.name = "system_override", .nargs = 2, .args = { ARG_INT, ARG_UNKNOWN, }},
	{.name = "vfs_purge", .nargs = 1, .args = { ARG_UNKNOWN, }},
};

#ifdef __cplusplus
}
#endif
